@@ -3,4 +3,6 @@ from enum import Enum
 
 class EnvType(Enum):
     PROD = 'prod'
+    PROD2 = 'prod2'
     QA = 'qa'
+    DEV = 'dev'
