@@ -76,6 +76,10 @@ class KeyCloakAPI:
             configuration.host = InsightServiceCfg.QA_BASE_URL
         elif self.env == EnvType.PROD:
             configuration.host = InsightServiceCfg.PROD_BASE_URL
+        elif self.env == EnvType.PROD2:
+            configuration.host = InsightServiceCfg.PROD2_BASE_URL
+        elif self.env == EnvType.DEV:
+            configuration.host = InsightServiceCfg.DEV_BASE_URL
         else:
             configuration.host = InsightServiceCfg.QA_BASE_URL
 
@@ -83,7 +87,7 @@ class KeyCloakAPI:
         try:
             # Generate access token
             api_response = keycloakApi.get_token(tenant=tenant, username=username,
-                                                 password=password)
+                                                 password=password, env=self.env)
             logging.info("auth api response: {0}".format(api_response))
             return api_response
         except ApiException as e:
